@@ -65,7 +65,7 @@ def do_sync_full_table(conn_config, stream, state, desired_columns, md_map):
                 state = full_table.sync_table(conn_config, stream, state, desired_columns, md_map)
             return state
         except Exception as e:
-            LOGGER.warn("error on read for a stream: %s. Message: %s", stream['tap_stream_id'], e)
+            LOGGER.error("error on read for a stream: %s. Message: %s", stream['tap_stream_id'], e)
             if attempt > post_db.TRY_NUMBER:
                 raise e
             else:
@@ -97,7 +97,7 @@ def do_sync_incremental(conn_config, stream, state, desired_columns, md_map):
             state = incremental.sync_table(conn_config, stream, state, desired_columns, md_map)
             return state
         except Exception as e:
-            LOGGER.warn("error on read for a stream: %s. Message: %s", stream['tap_stream_id'], e)
+            LOGGER.error("error on read for a stream: %s. Message: %s", stream['tap_stream_id'], e)
             if attempt > post_db.TRY_NUMBER:
                 raise e
             else:
